@@ -1363,62 +1363,62 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
       
       // Byte
       if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS && command_arg_type_dimension == 0) {
-        int8_t command_arg_int8 = env->get_field_byte_by_name(env, stack, obj_command_arg, "Byte", "value", &e, FILE_NAME, __LINE__);
+        int8_t command_arg_int8 = env->get_field_byte_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_int8);
 
-        env->set_field_byte_by_name(env, stack, obj_command_arg, "Byte", "value", command_arg_int8, &e, FILE_NAME, __LINE__);
+        env->set_field_byte_by_name(env, stack, obj_command_arg, "value", command_arg_int8, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Short
       else if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS && command_arg_type_dimension == 0) {
-        int16_t command_arg_int16 = env->get_field_short_by_name(env, stack, obj_command_arg, "Short", "value", &e, FILE_NAME, __LINE__);
+        int16_t command_arg_int16 = env->get_field_short_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_int16);
 
-        env->set_field_short_by_name(env, stack, obj_command_arg, "Short", "value", command_arg_int16, &e, FILE_NAME, __LINE__);
+        env->set_field_short_by_name(env, stack, obj_command_arg, "value", command_arg_int16, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Int
       else if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS && command_arg_type_dimension == 0) {
-        int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "Int", "value", &e, FILE_NAME, __LINE__);
+        int32_t command_arg_int32 = env->get_field_int_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_int32);
 
-        env->set_field_int_by_name(env, stack, obj_command_arg, "Int", "value", command_arg_int32, &e, FILE_NAME, __LINE__);
+        env->set_field_int_by_name(env, stack, obj_command_arg, "value", command_arg_int32, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Long
       else if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS && command_arg_type_dimension == 0) {
-        int64_t command_arg_int64 = env->get_field_long_by_name(env, stack, obj_command_arg, "Long", "value", &e, FILE_NAME, __LINE__);
+        int64_t command_arg_int64 = env->get_field_long_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_int64);
 
-        env->set_field_long_by_name(env, stack, obj_command_arg, "Long", "value", command_arg_int64, &e, FILE_NAME, __LINE__);
+        env->set_field_long_by_name(env, stack, obj_command_arg, "value", command_arg_int64, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Float
       else if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS && command_arg_type_dimension == 0) {
-        float command_arg_float = env->get_field_float_by_name(env, stack, obj_command_arg, "Float", "value", &e, FILE_NAME, __LINE__);
+        float command_arg_float = env->get_field_float_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_float);
 
-        env->set_field_float_by_name(env, stack, obj_command_arg, "Float", "value", command_arg_float, &e, FILE_NAME, __LINE__);
+        env->set_field_float_by_name(env, stack, obj_command_arg, "value", command_arg_float, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // Double
       else if (command_arg_basic_type_id == SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS && command_arg_type_dimension == 0) {
-        double command_arg_double = env->get_field_double_by_name(env, stack, obj_command_arg, "Double", "value", &e, FILE_NAME, __LINE__);
+        double command_arg_double = env->get_field_double_by_name(env, stack, obj_command_arg, "value", &e, FILE_NAME, __LINE__);
         if (e) { return e; }
         
         ret = fcntl(fd, command, &command_arg_double);
 
-        env->set_field_double_by_name(env, stack, obj_command_arg, "Double", "value", command_arg_double, &e, FILE_NAME, __LINE__);
+        env->set_field_double_by_name(env, stack, obj_command_arg, "value", command_arg_double, &e, FILE_NAME, __LINE__);
         if (e) { return e; }
       }
       // A pointer class
